#
# spec file for package tcpreplay
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tcpreplay
Version:        4.5.1
Release:        1.1
Summary:        Network analysis and testing tools
License:        GPL-3.0-only
Group:          Productivity/Networking/Diagnostic
URL:            https://tcpreplay.appneta.com/
Source0:        https://github.com/appneta/tcpreplay/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/appneta/tcpreplay/releases/download/v%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  dbus-1-devel
BuildRequires:  libdnet-devel
BuildRequires:  libpcap-devel
BuildRequires:  tcpdump
Requires:       tcpdump
%if 0%{?suse_version} >= 1130
BuildRequires:  libnl3-devel
%else
# only needed for suse_version < 1130 (i.e. SLE11)
BuildRequires:  xz
%endif

%description
Tcpreplay is a suite of utilities for editing and replaying
previously captured network traffic. It was originally designed to
replay malicious traffic patterns to Intrusion Detection/Prevention
Systems, and is meanwhile capable of replaying to web servers. It
supports switches, routers and IP Flow/NetFlow appliances.

%prep
%setup -q

%build
%configure \
  --enable-dynamic-link
%make_build

%install
%make_install

%files
%license docs/LICENSE
%doc docs/CHANGELOG
%{_bindir}/*
%{_mandir}/man1/*

%changelog
* Tue Dec 10 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 4.5.1:
  * AF_XDP socket support - if you have a newer Linux kernel, you will be able to transmit at line rates without having to install 3rd party kernel modules (e.g. netmap, PF_RING)
  * -w tcpreplay option - this overrides the -i option, and allows you to write to a PCAP file rather than an interface
  * --include and --exclude tcpreplay options - allows replay of a list of specific packet numbers to replay. This may slow things down, so consider using in combination with -w.
  * --fixhdrlen tcpreplay option - added to control action on packet length changes
  * -W tcpreplay option - suppress warnings when replaying
  * SLL2( Linux "cooked" capture encapsulation v2)
  * Haiku support
* Tue Jul 11 2023 Martin Hauke <mardnh@gmx.de>
- Update to 4.4.4:
  * overflow check fix for parse_mpls.
  * tcpreplay-edit: prevent L2 flooding of ipv6 unicast packets.
  * CVE-2023-27786: bugs caused by strtok_r. (boo#1209416)
  * CVE-2023-27783 reachable assert in tcpedit_dlt_cleanup
    (boo#1209413)
  * reachable assert in fast_edit_packet.
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 4.4.3:
  * upgrade autogen/libopts to version 5.18.16
  * avoid implicit int in configure.ac
  * remove invalid assert in tree
  * program exit after send error
  * make libpcap version test more robust
  * looping inflates some packet counters
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 4.4.2:
  * This is Tcpreplay suite 4.4.2
  * This release contains bug fixes only.
  * What's Changed
  * Bug #716 heap-buffer-overflow in get_l2len_protocol()
  * Bug #721 fixed typo in tcpliveplay.c
  * Bug #717 avoid assertion in get_layer4_v6
  * Bug #718 improved heap-overflow protection
  * Bug #719 better overflow protection in parse_mpls
  * Bug #725 FORCE_ALIGN on arm
  * Bug #729 tcpreplay_edit: disallow both -K and -l options
  * Bug #735 heap-overflow in get_l2len_protocol
  * Bug #745 remove autogen.sh from distribution tarballs
* Sun Jul 17 2022 Dirk Müller <dmueller@suse.com>
- update to 4.4.1:
  * fix support for feeding PCAP files from STDIN
  * fix Debian/kfreebsd build
  * fix typos
  * safeguard against corrupt packet lengths in checksum functions
  * fix double free in Juniper DLT
  * fix to flows.c, fix #665
  * update Travis CI to focal
  * LINUX installed netmap auto detection
  * Support for Q-in-Q VLAN tags
  * skipbroadcast
  * add security policy document
  * Directories of pcaps as arguments
  * stage PR from @halver94
  * fix PPS calc for long-running sessions
  * Improve SDK selection
  * fix directory include feature
  * mac os tests fail
  * Revert "send_packet: Avoid clock drift
  * mac update on multicast
* Sat May  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.3.4
  * Fixes ASAN reports memory leaks while running tests
  * clean up new_cidr_map() string manipulation on error exit
  * Fixed invalid --pps value protection
  * Fixed packets slowly drift further and further behind when they
    should be sent
  * Fixed 64 bit rollover can cause pps replay issues after several
    hours
  * DLT_NULL/DLT_LOOP support for cross-platform PF_INET6
  * Fixed heap buffer overflow in tcpreplay fast_edit_packet
  * Fixed heap buffer overflow in tcpreplay get_next_packet
  * Fixed CVE-2020-24266 heap buffer overflow in tcpprep get_l2len
  * Fixed CVE-2020-24265 heap buffer overflow in tcpprep
  * handle malformed and unsupported packets as soft errors
  * Fixed tcprewrite --fixlen not working on DLT conversion
  * Fixed with multiplier option only first file can be sent and hang
  * do not create tap0 if device already exists
* Mon Jun 15 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 4.3.3:
  * Increase cache buffers size to accomodate VLAN edits (#594)
  * Correct L2 header length to correct IP header offset (#583)
  * Fix warnings from gcc version 10 (#580)
  * Heap Buffer Overflow in randomize_iparp (#579)
  * Use after free in get_ipv6_next (#578)
  * Heap Buffer Overflow in git_ipv6_next (#576)
  * Call pcap_freecode() on pcap_compile() (#572)
  * Increase max snaplen to 262144 (#571)
  * Fix divide by zero in fuzzing (#570)
  * Unique IP repeats at very high iteration counts (#566)
  * Fails to compile on FreeBSD amd64 13.0 (#558)
  * Heap Buffer Overflow in do_checksum (#556) (#577)
  * Attempt to correct corrupt pcap files, if possible (#557)
  * Fix GCC v10 warnings (#555)
  * Remove some duplicated SOURCES entries (#551)
  * Expand /dev/bpfX hard limit to fix macOS Mojave (#550)
  * Implement –loopdelay-ms when using –loop=0 (#546)
  * Heap overflow packet2tree and get_l2len (#530)
* Fri Jun 12 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10
* Thu Mar 14 2019 seanlew@opensuse.org
- Update to version 4.3.2
  * CVE-2019-8381 memory access in do_checksum() (#538 bsc#1125753)
  * CVE-2019-8376 NULL pointer dereference get_layer4_v6() (#517 bsc#1125755)
  * CVE-2019-8377 NULL points dereference get_ipv6_i4proto() (#536 bsc#1125754)
  * Rename Ethereal to Wireshark (#545)
* Mon Dec 31 2018 sean@suspend.net
- Update to version 4.3.1:
  * Fix checkspell detected typos (#531)
  * Heap overflow packet2tree and get_l2len (#530)
- Update to version 4.3.0:
  * Fix TCP sequence edit seeding (#514)
  * Fix issues identified by Codacy (#493)
  * CVE-2018-18408 use-after-free in post_args (#489 bsc#1112354)
  * CVE-2018-18407 heap-buffer-overflow csum_replace4 (#488 bsc#1112355)
  * CVE-2018-17974 heap-buffer-overflow dlt_en10mb_encode (#486 bsc#1110786)
  * CVE-2018-17580 heap-buffer-overflow fast_edit_packet (#485 bsc#1110333)
  * CVE-2018-17582 heap-buffer-overflow in get_next_acket (#484 bsc#1110285)
  * Out-of-tree build (#483)
  * CVE-20180-13112 heap-buffer-overflow in get_l2len (#477)
  * Closing stdin on pipe (#479)
  * Second pcap file hangs on multiplier option (#466)
  * TCP sequence edit ACK corruption (#451)
  * TCP sequence number edit initial SYN packet should have 0 ACK (#450)
  * Travis CI build fails due to new build images (#432)
  * Upgrade libopts to 5.18.12 to address version build issues (#430)
  * Add ability to change tcp SEQ/ACK numbers (#425)
  * Hang using loop and netmap options (#424)
  * tcpprep -S not working for large cache files (#423)
  * Unable to tcprewrite range of ports with --portmap (#422)
  * --maxsleep broken for values less than 1000 (#421)
  * -T flag breaks traffic replay timing (#421)
  * Respect 2nd packet timing (#418)
  * Avoid non-blocking behaviour when using STDIN (#416)
  * pcap containing >1020 packets produces invalid cache file (#415)
  * manpage typos (#413)
  * Fails to open tap0 on Zephyr (#411)
  * Heap-buffer-overflow in get_l2protocol (#410)
  * Heap-buffer-overflow in packet2tree (#409)
  * Heap-buffer-overflow in getl2len (#408)
  * Heap-buffer-overflow in flow_decode (#407)
  * Rewrite zero IP total length field to match packet length (#406)
  * Stack-buffer-overflow in tcapinfo (#405)
  * tcpprep --include option does not exclude (#404)
  * Negative-size-param memset in dlt_radiotap_get_80211 (#402)
  * tcpreplay --verbose option not working (#398)
  * Fix replay when using --with-testnic (#178)
* Mon Sep 11 2017 jengelh@inai.de
- Trim history recap in description.
* Mon Jul 31 2017 mpluskal@suse.com
- Update to version 4.2.6:
  * Test fails on sparc64 (#393)
- Changes for version 4.2.5:
  * Fix issues found by scan-build (#384)
  * Improve --portmap help message (#381)
  * AFL detected security crash in fuzz feature (#380)
  * Coverity static scan detected issues (#374)
  * Fuzz should not be overwritting Layer 3 (#372)
  * Add --fuzz-factor option to specify fuzz ratio (#371)
  * Warnings when building on old distributions (#368)
  * Fix more Lintian detected spelling errors (#365)
  * Fuzz test failure on ARM and MIPS (#364)
- Changes for version 4.2.4:
  * Fix Lintian detected spelling errors (#362)
- Changes for version 4.2.3:
  * Archive (remove) QuickTX until maintainer found (#357)
  * Ubuntu precise 32bit_build (#356)
- Changes for version 4.2.2:
  * Archive (remove) QuickTX (#357)
  * Missing symbol pcap_version on macOS 10.12.4 (#356)
- Changes for version 4.2.1:
  * Fix reporting of rates < 1Mbps (#348)
  * Option --unique-ip not working properly (#346)
- Changes for version 4.2.0:
  * MAC rewriting capabilities (#313)
  * Fix several issues identified by Coverity (#305)
  * Packet destortion --fuzz-seed option by Gabriel Ganne (#302)
  * Add --unique-ip-loops option to modify IPs every few loops
    (#296)
  * Netmap startup delay increase (#290)
  * tcpcapinfo buffer overflow vulnerablily (#278)
  * Update git-clone instructions by Kyle McDonald (#277)
  * Allow fractions for --pps option (#270)
  * Print per-loop stats with --stats=0 (#269)
  * Add protection against packet drift by Guillaume Scott (#268)
  * Print flow stats periodically with --stats output (#262)
  * Include Travis-CI build support by Ilya Shipitsin (#264) (#285)
  * tcpreplay won't replay all packets in a pcap file with --netmap
    (#255)
  * First and last packet times in --stats output (#239)
  * Switch to wire speed after 30 minutes at 6 Gbps (#210)
  * tcprewrite fix checksum properly for fragmented packets (#190)
- Drop no longer needed patch (already in upstream):
  * 278-fail-if-capture-has-a-packet-that-is-too-large.patch
- Use %%make_install macro
- Update dependencies to support (libnl3 and dbus-1)
* Thu Mar 16 2017 mkubecek@suse.cz
- 278-fail-if-capture-has-a-packet-that-is-too-large.patch:
  buffer overflow in tcpcapinfo utility triggered by too large
  packet (CVE-2017-6429 bsc#1028234)
* Mon Nov 21 2016 mkubecek@suse.cz
- update to version 4.1.2
  * increase max packet size to 65549 (CVE-2016-6160 bsc#987846)
  * minor build fixes
* Wed Feb  3 2016 mkubecek@suse.cz
- add upstream changelog to docs
- minor specfile cleanup
* Sun Jan 31 2016 mpluskal@suse.com
- Install LICENSE
- Use url for source
- Add gpg signature
- Make building more verbose
- Cleanup spec file with spec-cleaner
* Thu Jan 28 2016 mkubecek@suse.cz
- run specfile through cleaner service to silence check scripts
* Tue Jan 12 2016 mkubecek@suse.cz
- update to version 4.1.1
  * various fixes
  * performance improvements
  * add --duration option which lets the user set the number of
    seconds to transmit
  * do not require --loop for --unique-ip
  * tun/tap support
  * support multiple CIDR ranges with tcprewrite
* Mon Mar  9 2015 mkubecek@suse.cz
- upgrade to version 4.1.0
  * Quick TX bypass module for Linux Kernel - allows Tcpreplay to
    bypass the kernel network stack and write directly to the
    network driver (disabled for now)
  * add a flag to customize netmap delay
  * add a loop delay option
  * fix: segfault in tcpliveplay on x86_64
  * fix: sometimes unable to interrupt with Ctrl-C
* Tue Nov 25 2014 mkubecek@suse.cz
- upgrade to version 4.0.5
  * various bugfixes; for details see
    https://github.com/appneta/tcpreplay/releases/tag/v4.0.5
* Wed May 28 2014 mkubecek@suse.cz
- upgrade to version 4.0.4
  * performance enhancements
  * IP flow / Netflow features
  * support netmap network drivers
  * new API
  * ARM support
  * new DLT support
- tcpreplay-3.4.4-overflow.patch:
  delete (no longer needed)
* Mon Nov 18 2013 mkubecek@suse.cz
- dynamic linking of libraries (fix build on >= 12.3)
* Thu Nov  3 2011 mkubecek@suse.cz
- initial package
- patch for buffer overflow in cidr2iplist()
